<?php
namespace Neklo\Scheduler\Helper;

use Magento\Store\Model\Store;
use Magento\Framework\App\Helper\Context;
use Magento\Store\Model\StoreManagerInterface;

class Config extends \Magento\Framework\App\Helper\AbstractHelper
{
    const GENERAL_ENABLED = 'neklo_scheduler/general/is_enabled';
    const GENERAL_MAX_JOB_RUNTIME = 'neklo_scheduler/general/max_job_runtime';
    const GENERAL_SCHEDULE = 'neklo_scheduler/general/scheduler_cron_expr_heartbeat';
    const GENERAL_MAX_TASKS = 'neklo_scheduler/general/maxNoOfSuccessfulTasks';

    const ERROR_ENABLE_LOG = 'neklo_scheduler/error/enable_log';
    const ERROR_MARK_AS_ERROR = 'neklo_scheduler/error/mark_as_error_after';
    const ERROR_EMAIL = 'neklo_scheduler/error/email';
    const ERROR_EMAIL_SENDER = 'neklo_scheduler/error/email_identity';
    const ERROR_EMAIL_TEMPLATE = 'neklo_scheduler/error/email_template';
    const ERROR_LOG_LEVEL = 'neklo_scheduler/error/level';
    const ERROR_LOG_FILENAME = 'neklo_scheduler/error/log_filename';

    const LOG_FILE = 'neklo_scheduler/log/file';
    const LOG_OUTPUT_BUFFER = 'neklo_scheduler/log/enable_job_output_buffer';

    /**
     *
     * @var \Magento\Store\Model\StoreManagerInterface
     */
    protected $_storeManager;
    /**
     *
     * @var \Magento\Store\Model\Store
     */
    protected $_store;

    public function __construct(
        Context $context,
        StoreManagerInterface $storeManager
    ) {
        parent::__construct($context);
        $this->_storeManager = $storeManager;
    }

    /**
     * Set current store
     *
     * @param  Store $store
     * @return void
     */
    public function setStore(Store $store)
    {
        $this->_store = $store;
    }

    /**
     * Return store
     *
     * @return Store
     */
    public function getStore()
    {
        //current store
        if (!$this->_store instanceof Store) {
            $this->setStore($this->_storeManager->getStore());
        }
        return $this->_store;
    }

    /**
     *
     * @param string $path
     * @param int    $store
     * @return string
     */
    public function getConfigValue($path, $store = null)
    {
        return $this->scopeConfig->getValue(
            $path,
            \Magento\Store\Model\ScopeInterface::SCOPE_STORE,
            $store ? $store : $this->getStore()->getStoreId()
        );
    }

    public function isEnabled($store = null)
    {
        return
            $this->getConfigValue(self::GENERAL_ENABLED, $store) != "disabled";
    }

    public function getMaxJobRuntime($store = null)
    {
        return $this->getConfigValue(self::GENERAL_MAX_JOB_RUNTIME, $store);
    }
    public function isCronExpr($store = null)
    {
        return $this->getConfigValue(self::GENERAL_SCHEDULE, $store);
    }
    public function getMaxNoOfSuccessfulTasks($store = null)
    {
        return $this->getConfigValue(self::GENERAL_MAX_TASKS, $store);
    }
    public function getEnabledRunNow($store = null)
    {
        return $this->getConfigValue(self::GENERAL_ENABLE_RUN, $store);
    }

    public function isEnabledErrorLog($store = null)
    {
        return $this->getConfigValue(self::ERROR_ENABLE_LOG, $store);
    }
    public function getMarkAsError($store = null)
    {
        return $this->getConfigValue(self::ERROR_MARK_AS_ERROR, $store);
    }
    public function getEmailRecipient($store = null)
    {
        return $this->getConfigValue(self::ERROR_EMAIL, $store);
    }
    public function getEmailSender($store = null)
    {
        return $this->getConfigValue(self::ERROR_EMAIL_SENDER, $store);
    }
    public function getEmailTemplate($store = null)
    {
        return $this->getConfigValue(self::ERROR_EMAIL_TEMPLATE, $store);
    }
    public function getErrorLevel($store = null)
    {
        return $this->getConfigValue(self::ERROR_LOG_LEVEL, $store);
    }
    public function getErrorLogFilename($store = null)
    {
        return $this->getConfigValue(self::ERROR_LOG_FILENAME, $store);
    }

    public function getLogFile($store = null)
    {
        return $this->getConfigValue(self::LOG_FILE, $store);
    }
    public function isEnabledJobOutputBuffer($store = null)
    {
        return $this->getConfigValue(self::LOG_OUTPUT_BUFFER, $store);
    }
}
